==> igniteui-react-16.16.2.tgz: package/esm5/lib/igr-pane-drag-start-event-args.js <==
import { PaneDragStartEventArgs as PaneDragStartEventArgs_internal } from "./PaneDragStartEventArgs";
var IgrPaneDragStartEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrPaneDragStartEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    }
    IgrPaneDragStartEventArgs.prototype.createImplementation = function () {
        return new PaneDragStartEventArgs_internal();
    };
    Object.defineProperty(IgrPaneDragStartEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrPaneDragStartEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrPaneDragStartEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
    };
    Object.defineProperty(IgrPaneDragStartEventArgs.prototype, "detail", {
        get: function () {
            if (this.i.a == null) {
                return null;
            }
            if (!this.i.a.externalObject) {
                var e = new IgrPaneDragStartEventArgs();
                e._implementation = this.i.a;
                this.i.a.externalObject = e;
            }
            return this.i.a.externalObject;
        },
        set: function (v) {
            v == null ? this.i.a = null : this.i.a = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrPaneDragStartEventArgs;
}());
export { IgrPaneDragStartEventArgs };

==> igniteui-react-18.5.1.tgz: package/esm5/lib/igr-pane-drag-start-event-args.js <==
import { IgrPaneDragStartEventArgsDetail } from "./igr-pane-drag-start-event-args-detail";
import { PaneDragStartEventArgs as PaneDragStartEventArgs_internal } from "./PaneDragStartEventArgs";
var IgrPaneDragStartEventArgs = /** @class */ /*@__PURE__*/ (function () {
    function IgrPaneDragStartEventArgs() {
        this._implementation = this.createImplementation();
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    }
    IgrPaneDragStartEventArgs.prototype.createImplementation = function () {
        return new PaneDragStartEventArgs_internal();
    };
    Object.defineProperty(IgrPaneDragStartEventArgs.prototype, "i", {
        /**
         * @hidden
         */
        get: function () {
            return this._implementation;
        },
        enumerable: false,
        configurable: true
    });
    IgrPaneDragStartEventArgs.prototype.onImplementationCreated = function () {
    };
    IgrPaneDragStartEventArgs.prototype._provideImplementation = function (i) {
        this._implementation = i;
        this._implementation.externalObject = this;
        this.onImplementationCreated();
        if (this._initializeAdapters) {
            this._initializeAdapters();
        }
    };
    Object.defineProperty(IgrPaneDragStartEventArgs.prototype, "detail", {
        get: function () {
            var r = this.i.b;
            if (r == null) {
                return null;
            }
            if (!r.externalObject) {
                var e = new IgrPaneDragStartEventArgsDetail();
                if (r.$type) {
                    e._implementation = r;
                }
                else {
                    if (e.i.setNativeElement) {
                        e.i.setNativeElement(r);
                    }
                }
                r.externalObject = e;
            }
            return r.externalObject;
        },
        set: function (v) {
            v == null ? this.i.b = null : this.i.b = v.i;
        },
        enumerable: false,
        configurable: true
    });
    return IgrPaneDragStartEventArgs;
}());
export { IgrPaneDragStartEventArgs };
